==> guildai-0.8.2-py2.py3-none-any.whl: guild/tests/api-runs.md <==
# Guild `api runs` command

Generate some sample runs.

    >>> project = Project(sample("projects", "hello"))

    >>> project.run("hello-file")
    Resolving file
    Using hello.txt for file resource
    Reading message from hello.txt
    Hello, from a file!
    <BLANKLINE>
    Saving message to msg.out

Helper for running commands for the project.

    >>> def project_cmd(cmd):
    ...     run(f"guild -H {project.guild_home} {cmd}", cwd=project.cwd)

## `api runs`

    >>> project_cmd("api runs -f")  # doctest: +REPORT_UDIFF
    [
      {
        "command": "... -um guild.op_main cat -- --file hello.txt",
        "comments": [],
        "deps": [],
        "dir": "...",
        "env": {
          ...
        },
        "exitStatus": 0,
        "files": [
          {
            "icon": "file-document",
            "iconTooltip": "Text file",
            "mtime": ...,
            "operation": null,
            "path": "hello.txt",
            "run": null,
            "size": 20,
            "type": "Text file",
            "viewer": "text"
          },
          {
            "icon": "file-document",
            "iconTooltip": "Text file",
            "mtime": ...,
            "operation": null,
            "path": "msg.out",
            "run": null,
            "size": ...,
            "type": "Text file",
            "viewer": "text"
          }
        ],
        "flags": {
          "file": "hello.txt"
        },
        "id": "...",
        "label": "file=hello.txt",
        "opRef": {
          "modelName": "",
          "opName": "hello-file",
          "pkgName": ".../samples/projects/hello/guild.yml",
          "pkgType": "guildfile",
          "pkgVersion": "..."
        },
        "operation": "hello-file",
        "otherAttrs": {},
        "projectDir": ".../samples/projects/hello",
        "scalars": [],
        "shortId": "...",
        "sourcecode": {
          "files": [
            "README.md",
            "cat.py",
            "guild.yml",
            "hello.txt",
            "repeat.py",
            "say.py"
          ],
          "root": ".guild/sourcecode"
        },
        "started": "...",
        "status": "completed",
        "stopped": "...",
        "tags": "",
        "time": "0:00:..."
      }
    ]
    <exit 0>

==> guildai-0.9.0rc1-py2.py3-none-any.whl: guild/tests/api-runs.md <==
# Guild `api runs` command

Generate some sample runs.

    >>> use_project("hello")

    >>> run("guild run hello-file -y")
    Reading message from hello.txt
    Hello, from a file!
    <BLANKLINE>
    Saving message to msg.out

## `api runs`

    >>> run("guild api runs -f")  # doctest: +REPORT_UDIFF
    [
      {
        "command": "... -um guild.op_main cat -- --file hello.txt",
        "comments": [],
        "deps": [],
        "dir": "...",
        "env": {
          ...
        },
        "exitStatus": 0,
        "files": [
          {
            "mtime": ...,
            "operation": null,
            "path": "README.md",
            "run": null,
            "size": 135
          },
          {
            "mtime": ...,
            "operation": null,
            "path": "cat.py",
            "run": null,
            "size": 294
          },
          {
            "mtime": ...,
            "operation": null,
            "path": "guild.yml",
            "run": null,
            "size": 502
          },
          {
            "mtime": ...,
            "operation": null,
            "path": "hello.txt",
            "run": null,
            "size": 20
          },
          {
            "mtime": ...,
            "operation": null,
            "path": "msg.out",
            "run": null,
            "size": ...
          },
          {
            "mtime": ...,
            "operation": null,
            "path": "repeat.py",
            "run": null,
            "size": 103
          },
          {
            "mtime": ...,
            "operation": null,
            "path": "say.py",
            "run": null,
            "size": 36
          }
        ],
        "flags": {
          "file": "hello.txt"
        },
        "id": "...",
        "label": "file=hello.txt",
        "marked": false,
        "opRef": {
          "modelName": "",
          "opName": "hello-file",
          "pkgName": ".../samples/projects/hello/guild.yml",
          "pkgType": "guildfile",
          "pkgVersion": "..."
        },
        "operation": "hello-file",
        "otherAttrs": {},
        "projectDir": ".../samples/projects/hello",
        "scalars": [],
        "shortId": "...",
        "sourcecode": {
          "files": [
            "README.md",
            "cat.py",
            "guild.yml",
            "hello.txt",
            "repeat.py",
            "say.py"
          ],
          "root": "."
        },
        "started": ...,
        "status": "completed",
        "stopped": ...,
        "tags": []
      }
    ]
    <exit 0>
